@@ -27,7 +27,7 @@
  * list of people on the gedit Team.  
  * See the ChangeLog files for a list of changes. 
  *
- * $Id: gedit-utils.h,v 1.36 2005/12/29 15:13:39 pborelli Exp $
+ * $Id: gedit-utils.h,v 1.37.2.1 2006/04/20 16:53:41 pborelli Exp $
  */
 
 #ifndef __GEDIT_UTILS_H__
@@ -129,6 +129,14 @@ gboolean	 gedit_utils_get_glade_widgets		(const gchar  *filename,
 							 const gchar  *widget_name,
 							 ...) G_GNUC_NULL_TERMINATED;
 
+/* Return NULL if str is not a valid URI and/or filename */
+gchar		*gedit_utils_make_canonical_uri_from_shell_arg
+							(const gchar *str);
+		
+/* Like gnome_vfs_format_uri_for_display but removes the password from the 
+ * resulting string */
+gchar		*gedit_utils_format_uri_for_display 	(const gchar *uri);
+
 G_END_DECLS
 
 #endif /* __GEDIT_UTILS_H__ */
